@@ -2,6 +2,8 @@ import os
 import sys
 import csv
 import re
+from math import ceil
+import multiprocessing
 from datetime import datetime
 import pytz
 import yaml
@@ -72,4 +74,38 @@ def get_csv_dialect(csv_path):
 
 def replace_date_punct(datemonth_str):
     """removes year-month punctuation and returns str("000000")"""
-    return re.sub("[-_.: ]", "", datemonth_str) if datemonth_str is not None else ""
\ No newline at end of file
+    return re.sub("[-_.: ]", "", datemonth_str) if datemonth_str is not None else ""
+
+
+def get_pool_cpu_count(count=None):
+
+    try:
+        real_vcpu_count = multiprocessing.cpu_count()
+
+        if count is None:
+            count = real_vcpu_count
+        else:
+            err_text_cpu_level_err = \
+            f"""
+                    ERROR on -c {count}  ERROR
+                        * Malformed command:
+                            - -c cpu must be str: low, medium, or high. or integer percent 1-200
+            """
+            count = str(count)
+            match count:
+                case "low":
+                    count = ceil(real_vcpu_count / 2.5)
+                case "medium":
+                    count = ceil(real_vcpu_count / 1.5)
+                case "high":
+                    count = real_vcpu_count
+                case _:
+                    if count.isnumeric() and 1 <= int(count) <= 200:
+                        count =  ceil(real_vcpu_count * (int(count) / 100))
+                    else:
+                        raise ValueError(err_text_cpu_level_err)
+
+        return count - 1 if count > 2 else ceil(count / 2)
+    except ValueError as err:
+        print(err)
+        sys.exit(err)
\ No newline at end of file
